aboutsummaryrefslogtreecommitdiffstats
path: root/include/osmocom/bsc/acc_ramp.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/osmocom/bsc/acc_ramp.h')
-rw-r--r--include/osmocom/bsc/acc_ramp.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/include/osmocom/bsc/acc_ramp.h b/include/osmocom/bsc/acc_ramp.h
index 39f10ccad..46a14c869 100644
--- a/include/osmocom/bsc/acc_ramp.h
+++ b/include/osmocom/bsc/acc_ramp.h
@@ -77,13 +77,18 @@ struct acc_ramp {
};
/*
- * Initialize an acc_ramp data structure.
+ * Initialize the acc_ramp data structure.
* Storage for this structure must be provided by the caller.
* The BTS which uses this ACC ramp must be provided as well to allow for automatic
* scaling of the timeout imterval based on BTS channel load average.
* All ACCs are allowed by default. Call acc_ramp_start() next to initiate the ramping process.
*/
-void acc_ramp_init(struct acc_ramp *acc_ramp, struct gsm_bts *bts);
+void acc_ramp_init(struct acc_ramp *acc_ramp, struct gsm_bts *bts, bool ramping_enabled);
/* Change the ramping step size. Returns negative on error (step_size out of range), else zero. */
int acc_ramp_set_step_size(struct acc_ramp *acc_ramp, enum acc_ramp_step_size step_size);
@@ -77,13 +77,18 @@ struct acc_ramp {
* Storage for this structure must be provided by the caller.
- * The BTS which uses this ACC ramp must be provided as well to allow for automatic
- * scaling of the timeout imterval based on BTS channel load average.
- * All ACCs are allowed by default. Call acc_ramp_start() next to initiate the ramping process.
+ *
+ * The BTS which uses this ACC ramp must be provided as well.
+ *
+ * If 'ramping_enabled' is true, all ACCs are denied by default.
+ * A subsequent call to acc_ramp_start() will begin the ramping process.
+ *
+ * If 'ramping_enabled' is false, all ACCs will be allowed by default, and
+ * there is no need to do anything else.
*/